library(testthat)
library(GLMcat)

# test_check("GLMcat")
